@@ -5,8 +5,10 @@ module RequestStore
     end
 
     def call(env)
+      RequestStore.begin!
       @app.call(env)
     ensure
+      RequestStore.end!
       RequestStore.clear!
     end
   end
